@@ -1,6 +1,6 @@
 package AnyEvent::ProcessPool::Pipeline;
 # ABSTRACT: A simplified, straightforward way to parallelize tasks
-$AnyEvent::ProcessPool::Pipeline::VERSION = '0.03';
+$AnyEvent::ProcessPool::Pipeline::VERSION = '0.04';
 
 use strict;
 use warnings;
@@ -15,7 +15,7 @@ sub pipeline (%) {
   my %param = @_;
   my $in    = delete $param{in};
   my $out   = delete $param{out};
-  my $pool  = AnyEvent::ProcessPool->new(%param);
+  my $pool  = delete $param{pool} || AnyEvent::ProcessPool->new(%param);
   my $count = 0;
 
   my %pending;
@@ -47,7 +47,7 @@ AnyEvent::ProcessPool::Pipeline - A simplified, straightforward way to paralleli
 
 =head1 VERSION
 
-version 0.03
+version 0.04
 
 =head1 SYNOPSIS
 
@@ -75,6 +75,12 @@ until C<in> returns an empty list, after which it will continue to run until
 all pending results have been delivered. C<pipeline> returns the total number
 of tasks processed.
 
+Optionally, an existing pool may be specified using the C<pool> parameter.
+
+  pipeline pool => $pool,
+    in  {...},
+    out {...};
+
 Aside from C<in> and C<out>, all other arguments are passed unchanged to
 L<AnyEvent::ProcessPool>'s constructor.
 
