@@ -1,6 +1,6 @@
 package AnyEvent::ProcessPool::Process;
 # ABSTRACT: Manages an individual worker process
-$AnyEvent::ProcessPool::Process::VERSION = '0.03';
+$AnyEvent::ProcessPool::Process::VERSION = '0.04';
 use strict;
 use warnings;
 
@@ -80,12 +80,7 @@ sub start {
       my ($ps, $line) = @_;
       my $task = AnyEvent::ProcessPool::Task->decode($line);
       my $cv = shift @{$self->{pending}};
-
-      if ($task->failed) {
-        $cv->croak($task->result);
-      } else {
-        $cv->send($task->result);
-      }
+      $cv->send($task);
 
       if ($self->{limit} && $ps->user->{reqs} <= 0) {
         $self->stop;
@@ -115,13 +110,12 @@ sub start {
 }
 
 sub run {
-  my ($self, $code, $args) = @_;
+  my ($self, $task) = @_;
   $self->await;
 
   my $cv = AE::cv;
   push @{$self->{pending}}, $cv;
 
-  my $task = AnyEvent::ProcessPool::Task->new($code, $args);
   $self->{ps}->say($task->encode);
   --$self->{ps}->user->{reqs} if $self->{limit};
 
@@ -142,7 +136,7 @@ AnyEvent::ProcessPool::Process - Manages an individual worker process
 
 =head1 VERSION
 
-version 0.03
+version 0.04
 
 =head1 AUTHOR
 
